@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import sys
+import traceback
 import tempfile
 import subprocess
 
@@ -44,6 +45,10 @@ class DependencyResolver(object):
             print "." * len(command)
 
         if len(dependencies) is 0:
+            sys.stderr.write(traceback.format_exc(error))
+            sys.stderr.write("\n")
+            sys.stderr.write("." * 20)
+            sys.stderr.write("\n")
             raise error
         else:
             print "=" * 10
